nmadt.hierarchical.MNAR performs meta-analysis using the hierarchical model Ma2018NMADTA based on the missing not at random(MNAR) assumption.
nmadt.hierarchical.MNAR(
nstu,
K,
data,
testname,
directory = NULL,
diag = 5,
off_diag = 0.05,
digits = 4,
mu_alpha = 0,
mu_beta = 0,
mu_eta = -0,
preci_alpha = 0.1,
preci_beta = 0.1,
preci_eta = 0.1,
gamma1,
gamma0,
mu_gamma = 0,
preci_gamma = 1,
n.burnin = floor(n.iter/2),
n.thin = max(1, floor((n.iter - n.burnin)/1e+05)),
n.adapt = 5000,
n.iter = 50000,
n.chains = 3,
conv.diag = FALSE,
trace = NULL,
dic = FALSE,
mcmc.samples = FALSE
)A list with the raw output for graphing the results, the effect size estimates, which lists the posterior mean, standard deviation, median, and a $95$% equal tail credible interval for the median.
an integer indicating the number of studies included in the dataset.
an integer indicating the number of candidate test in the dataset.
a list containing the input dataset to be used for meta-analysis.
a string vector of the names of the candidate tests in the dataset in the same order as presetned in the dataset.
a string specifying the designated directory to save trace plots or potential scale reduction factors calculated in the function. The default is NULL.
A number specifying the diagonal entries of the scale matrix $R$ in the
Wishart prior for the precision matrix \(\Sigma^{-1}\). Larger values of diag
typically imply stronger prior shrinkage, favoring smaller between-study variability in
prevalence, sensitivity, and specificity. The default is 5.
A number specifying the off-diagonal entries of the scale matrix $R$ in the
Wishart prior for \(\Sigma^{-1}\), controlling the strength of prior dependence among
random effects (e.g., correlations between sensitivity and specificity and their association
with prevalence). The default is 0.05. If strong correlations are expected, users may
increase off_diag; if substantially larger heterogeneity is anticipated, users may
decrease diag. We recommend sensitivity analyses alongside standard MCMC diagnostics.
A positive integer specifying the number of digits to the right of the decimal
point to keep in the printed results; the default is digits = 4.
a number indicating the mean of the normal distribution that the prior of the fixed effect for sensitivity follows. The default is 0.
a number indicating the mean of the normal distribution that the prior of the fixed effect for specificity follows. The default is 0.
a number indicating the mean of the normal distribution that the prior of the fixed effect for prevalence follows. The default is 0.
a number indicating the precision of the normal distribution that the prior of the fixed effect for sensitivity follows. The default is $0.1$.
a number indicating the precision of the normal distribution that the prior of the fixed effect for specificity follows. The default is $0.1$.
a number indicating the precision of the normal distribution that the prior of the fixed effect for prevalence follows. The default is $0.1$.
A numeric vector (length K) for coefficients on \(\text{logit}(\text{Se}_{ik})\)
in the MNAR missingness model. Recommended to treat as sensitivity-analysis parameters.
See gamma0 for suggested grids and interpretation.
A numeric vector (length K) for coefficients on \(\text{logit}(\text{Sp}_{ik})\)
in the MNAR missingness model. Recommended to treat as sensitivity-analysis parameters.
\(\gamma_{0k}=0\) corresponds to MAR with respect to accuracy; negative values
(e.g., c(0, -0.5, -1, -2)) represent the common assumption that tests with poorer accuracy
are more likely to be missing.
a number specifying mean of intercept in the MNAR model. The default is 0.
a number specifying precision of intercept in the MNAR model. The default is 1.
a positive integer indicating the number of burn-in iterations at the beginning of each chain without saving any of the posterior samples. The default is floor(n.iter/2).
the thinning rate for MCMC chains, which is used to save memory and computation time when n.iter is large.
For example, the algorithm saves only one sample in every nth iteration, where n is given by n.thin.
a positive integer indicating the number of iterations for adaptation. The default is 5,000.
a positive integer indicating the number of iterations in each MCMC chain. The default is 50,000.
a positive integer indicating the number of MCMC chains. The default is 3.
a logical value specifying whether to compute potential scale reduction factors proposed for convergence diagnostics. The default is FALSE.
a string vector containing a subset of different quantities which can be chosen from prevalence("prev"), sensitivity ("Se"), specificity ("Sp"), positive and negative predictive values ("ppv" and "npv" repectively), positive likelihood ("LRpos"), and negative likelihood ("LRneg").
a logical value indicating whether the function will output the deviance information criterion (DIC) statistic. The default is false.
a logical value indicating whether the coda samples generated in the meta-analysis. The default is FALSE.
Ma2018NMADTA
data(dat.kang)
set.seed(9)
kang.out <- nmadt.hierarchical.MNAR(nstu = 12, K = 2, data = dat.kang,
directory = tempdir(),
testname = c("D-dimer", "Ultrasonography"),
n.adapt = 1000, n.iter = 1000, n.chains = 3,
gamma1=c(-0.5,-0.5), gamma0=c(-0.5,-0.5))
Run the code above in your browser using DataLab