Learn R Programming

NMADTA (version 0.1.2)

nmadt.hsroc.MNAR: HSROC Model for Network Meta-Analysis of Diagnostic Accuracy Studies Under MNAR Assumptions

Description

nmadt.hsroc.MNAR performs network meta-analysis of diagnostic tests using the HSROC (hierarchical summary receiver operating characteristic) model lian2018bayesianNMADTA based on the MNAR assumption.

Usage

nmadt.hsroc.MNAR(
  nstu,
  K,
  data,
  testname,
  directory = NULL,
  eta = 0,
  xi_preci = 1.25,
  digits = 4,
  gamma1,
  gamma0,
  mu_gamma = 0,
  preci_gamma = 1,
  n.adapt = 10000,
  n.iter = 50000,
  n.chains = 3,
  n.burnin = floor(n.iter/2),
  n.thin = max(1, floor((n.iter - n.burnin)/1e+05)),
  conv.diag = FALSE,
  trace = NULL,
  dic = FALSE,
  mcmc.samples = FALSE
)

Value

A list with the raw output for graphing the results, the effect size estimates, which lists the posterior mean, standard deviation, median, and a $95$% equal tail credible interval for the median.

Arguments

nstu

an integer indicating the number of studies included in the dataset.

K

an integer indicating the number of candidate test in the dataset.

data

a list containing the input dataset to be used for meta-analysis.

testname

a string vector of the names of the candidate tests in the dataset in the same order as presetned in the dataset.

directory

a string specifying the designated directory to save trace plots or potential scale reduction factors calculated in the function. The default is NULL.

eta

a number indicating the mean of log(S) and log(P) which determines the covariance matrices of the cutoff values and accuracy values respectively. The default is 0.

xi_preci

a number indicating the precision of log(S) and log(P) which determines the covariance matrices of the cutoff values and accuracy values respectively. The default is 1.25.

digits

a positive integer he number of digits to the right of the decimal point to keep for the results; digits=4 by default.

gamma1

A numeric vector (length K) for coefficients on \(\text{logit}(\text{Se}_{ik})\) in the MNAR missingness model. Recommended to treat as sensitivity-analysis parameters. See gamma0 for suggested grids and interpretation.

gamma0

A numeric vector (length K) for coefficients on \(\text{logit}(\text{Sp}_{ik})\) in the MNAR missingness model. Recommended to treat as sensitivity-analysis parameters. \(\gamma_{0k}=0\) corresponds to MAR with respect to accuracy; negative values (e.g., c(0, -0.5, -1, -2)) represent the common assumption that tests with poorer accuracy are more likely to be missing.

mu_gamma

a number specifying mean of intercept in the MNAR model. The default is 0.

preci_gamma

a number specifying precision of intercept in the MNAR model. The default is 1.

n.adapt

a positive integer indicating the number of iterations for adaptation. The default is 5,000.

n.iter

a positive integer indicating the number of iterations in each MCMC chain. The default is 50,000.

n.chains

a positive integer indicating the number of MCMC chains. The default is 3.

n.burnin

a positive integer indicating the number of burn-in iterations at the beginning of each chain without saving any of the posterior samples. The default is floor(n.iter/2).

n.thin

the thinning rate for MCMC chains, which is used to save memory and computation time when n.iter is large. For example, the algorithm saves only one sample in every nth iteration, where n is given by n.thin.

conv.diag

a logical value specifying whether to compute potential scale reduction factors proposed for convergence diagnostics. The default is FALSE.

trace

a string vector containing a subset of different quantities which can be chosen from prevalence("prev"), sensitivity ("Se"), specificity ("Sp"), positive and negative predictive values ("ppv" and "npv" repectively), positive likelihood ("LRpos"), and negative likelihood ("LRneg").

dic

a logical value indicating whether the function will output the deviance information criterion (DIC) statistic. The default is false.

mcmc.samples

a logical value indicating whether the coda samples generated in the meta-analysis. The default is FALSE.

References

lian2018bayesianNMADTA

Examples

Run this code
# \donttest{
data(dat.kang)
set.seed(9)
kangMNAR.out.hsroc <- nmadt.hsroc.MNAR(nstu=12, K=2, data=dat.kang,
testname=c("D-dimer","Ultrasonography"),gamma1=c(-0.5,-0.5), gamma0=c(-0.5,-0.5))
# }

Run the code above in your browser using DataLab